function results = ipcm_transitional(X,f,M,pident,identif,start,order,interaction)
% this is a program to perform ideal point classification model
% for transitional repeated measures model 
% INPUT
%   X: Matrix with explanatory variables (N*p)
%   f: vector with choice categories (values: 1,2, ..G)
%   M: dimensionality of the Euclidean Space
%   pident: identificationnumber of persons
%   identif: fit model ('none') or only produce correct data ('data')
%   start: manova == starting values from a manova else starting values
%   order: order of auto-regression function
%   interaction = 1 if there is ineteraction between previous choice and
%           explanatory variables
% OUTPUT 
%   result structure with:
%       .w = masses
%       .B = regression terms
%       .Y= ideal points
%       .Z= class points
%       .parameters= complete parameter vector
%       .loglik= value of the loglikelihood optimization function 
%       .npar= number of parameters
%       .BIC = BIC value
%       .grad = gradient from fminunc
%       .hessian = hessian from fminunc
% (c) Mark de Rooij, 04-09-2007.

% adapt predictor variables matrix for autogressive part
% basic reference Bonney (1987) Biometrics
if size(f,2)==1;F=dummyvar(f);else F=f;end
p1=size(X,2);p2=size(F,2)-1;
[ni,n]=counti(pident);
ni=ni';nstart = [1; cumsum(ni)+1];
%FF=F(:,1:end-1);FF=FF+(sum(FF,2)==0)*(-ones(1,size(FF,2)));% last category baseline
FF=F(:,2:end);FF=FF+(sum(FF,2)==0)*(-ones(1,size(FF,2)));% first category baseline
if isempty(X);X=ones(size(F,1),1);wasempty = true;else;wasempty = false;end
xx{1}=X;
for teller=1:order
    for j=1:n
        ff=[zeros(teller,size(FF,2));FF(nstart(j):nstart(j+1)-1-teller,:)];
        xx{teller+1}(nstart(j):nstart(j+1)-1,:)=[xx{teller}(nstart(j):nstart(j+1)-1,:),ff];% lagged variable aan het eind!!
    end
end
X=xx{teller+1};
if wasempty;X=X(:,2:end);end
if interaction
    model=[eye(p1+p2);[kron(eye(p1),ones(p2,1)) kron(ones(p1,1),eye(p2))]];
    X=x2fx(X,model);
end
% delete first observations 
nstart=nstart(1:end-1);
X(nstart,:)=[];F(nstart,:)=[];
% check input
[N1,p] = size(X);
[N2,G] = size(F);
if N1 ~= N2; error('number of rows in X and F needs to be the same');end
if M > G-1; error('dimensionality is out of bounds (must be <= than # groups - 1)');end

switch lower(identif)
    case{'none'}
        results = ipcm1_transitional(X,F,M,pident,start);
        results.X=X;
        results.F=F;
    case{'data'}
        results=X;% this returns the extended predictor matrix.
        results.F=F;
end
% if masses are wanted ipcm4